"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createE2EClient = void 0;
const apollo_boost_1 = require("apollo-boost");
const apollo_link_http_1 = require("apollo-link-http");
const p_retry_1 = __importDefault(require("p-retry"));
const cross_fetch_1 = __importDefault(require("cross-fetch"));
const util_1 = __importDefault(require("@cardano-graphql/util"));
exports.createE2EClient = () => __awaiter(void 0, void 0, void 0, function* () {
    const client = new apollo_boost_1.ApolloClient({
        cache: new apollo_boost_1.InMemoryCache({
            addTypename: false
        }),
        defaultOptions: {
            query: {
                fetchPolicy: 'network-only'
            }
        },
        link: apollo_link_http_1.createHttpLink({
            uri: process.env.CARDANO_GRAPHQL_URI || 'http://localhost:3100',
            fetch: cross_fetch_1.default
        })
    });
    yield p_retry_1.default(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.query({
            query: apollo_boost_1.gql `query {
          cardano {
              tip { 
                  number
              }
              currentEpoch {
                  number
              }
          }}`
        });
    }), {
        factor: 1.75,
        retries: 9,
        onFailedAttempt: util_1.default.onFailedAttemptFor('Cardano GraphQL Server readiness')
    });
    return client;
});
//# sourceMappingURL=e2e_client.js.map